# Changelog

## 🚀 xcollection v2021.12.23 🚀 (Unreleased)

## 🚀 xcollection v2021.12.01 🚀

([full changelog](https://github.com/NCAR/xcollection/compare/v2021.11.24...v2021.12.01))

### Enhancements made

- Add `open_collection()` and add `to_zarr()` to Collection [#26](https://github.com/NCAR/xcollection/pull/26) ([@mgrover1](https://github.com/mgrover1))

### Documentation improvements

- Add documentation template [#30](https://github.com/NCAR/xcollection/pull/30) ([@andersy005](https://github.com/andersy005))
- Use mamba when building docs on Readthedocs [#29](https://github.com/NCAR/xcollection/pull/29) ([@andersy005](https://github.com/andersy005))

### Other merged PRs

- [pre-commit.ci] pre-commit autoupdate [#31](https://github.com/NCAR/xcollection/pull/31) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- Create pypi-release.yaml [#28](https://github.com/NCAR/xcollection/pull/28) ([@jukent](https://github.com/jukent))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/NCAR/xcollection/graphs/contributors?from=2021-11-24&to=2021-11-29&type=c))

[@andersy005](https://github.com/search?q=repo%3ANCAR%2Fxcollection+involves%3Aandersy005+updated%3A2021-11-24..2021-11-29&type=Issues) | [@jukent](https://github.com/search?q=repo%3ANCAR%2Fxcollection+involves%3Ajukent+updated%3A2021-11-24..2021-11-29&type=Issues) | [@mgrover1](https://github.com/search?q=repo%3ANCAR%2Fxcollection+involves%3Amgrover1+updated%3A2021-11-24..2021-11-29&type=Issues) | [@pre-commit-ci](https://github.com/search?q=repo%3ANCAR%2Fxcollection+involves%3Apre-commit-ci+updated%3A2021-11-24..2021-11-29&type=Issues)

## 🚀 xcollection v2021.11.24 🚀

([full changelog](https://github.com/NCAR/xcollection/compare/973126a20e011f3030ceffab0d6c2c2ba8431365...v2021.11.24))

### Enhancements made

- Add keymap method [#21](https://github.com/NCAR/xcollection/pull/21) ([@andersy005](https://github.com/andersy005))
- Add `map` method to map a callable to all datasets in Collection [#5](https://github.com/NCAR/xcollection/pull/5) ([@andersy005](https://github.com/andersy005))
- Add `choose_any` and `choose_all` methods [#3](https://github.com/NCAR/xcollection/pull/3) ([@andersy005](https://github.com/andersy005))
- Add Collection Object [#2](https://github.com/NCAR/xcollection/pull/2) ([@andersy005](https://github.com/andersy005))

### Maintenance and upkeep improvements

- [pre-commit.ci] pre-commit autoupdate [#25](https://github.com/NCAR/xcollection/pull/25) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- [pre-commit.ci] pre-commit autoupdate [#24](https://github.com/NCAR/xcollection/pull/24) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- [pre-commit.ci] pre-commit autoupdate [#23](https://github.com/NCAR/xcollection/pull/23) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- [pre-commit.ci] pre-commit autoupdate [#22](https://github.com/NCAR/xcollection/pull/22) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- [pre-commit.ci] pre-commit autoupdate [#19](https://github.com/NCAR/xcollection/pull/19) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- [pre-commit.ci] pre-commit autoupdate [#18](https://github.com/NCAR/xcollection/pull/18) ([@pre-commit-ci](https://github.com/pre-commit-ci))

### Other merged PRs

- Create pypi-release.yaml [#28](https://github.com/NCAR/xcollection/pull/28) ([@jukent](https://github.com/jukent))
- Upgrade setup/build requirements [#20](https://github.com/NCAR/xcollection/pull/20) ([@andersy005](https://github.com/andersy005))
- Add Weighted Method to Collection Object [#12](https://github.com/NCAR/xcollection/pull/12) ([@jukent](https://github.com/jukent))
- Bump codecov/codecov-action from 2.0.3 to 2.1.0 [#11](https://github.com/NCAR/xcollection/pull/11) ([@dependabot](https://github.com/dependabot))
- [pre-commit.ci] pre-commit autoupdate [#10](https://github.com/NCAR/xcollection/pull/10) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- Bump codecov/codecov-action from 2.0.2 to 2.0.3 [#9](https://github.com/NCAR/xcollection/pull/9) ([@dependabot](https://github.com/dependabot))
- [pre-commit.ci] pre-commit autoupdate [#8](https://github.com/NCAR/xcollection/pull/8) ([@pre-commit-ci](https://github.com/pre-commit-ci))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/NCAR/xcollection/graphs/contributors?from=2021-08-01&to=2021-11-24&type=c))

[@andersy005](https://github.com/search?q=repo%3ANCAR%2Fxcollection+involves%3Aandersy005+updated%3A2021-08-01..2021-11-24&type=Issues) | [@dcherian](https://github.com/search?q=repo%3ANCAR%2Fxcollection+involves%3Adcherian+updated%3A2021-08-01..2021-11-24&type=Issues) | [@dependabot](https://github.com/search?q=repo%3ANCAR%2Fxcollection+involves%3Adependabot+updated%3A2021-08-01..2021-11-24&type=Issues) | [@jukent](https://github.com/search?q=repo%3ANCAR%2Fxcollection+involves%3Ajukent+updated%3A2021-08-01..2021-11-24&type=Issues) | [@kmpaul](https://github.com/search?q=repo%3ANCAR%2Fxcollection+involves%3Akmpaul+updated%3A2021-08-01..2021-11-24&type=Issues) | [@matt-long](https://github.com/search?q=repo%3ANCAR%2Fxcollection+involves%3Amatt-long+updated%3A2021-08-01..2021-11-24&type=Issues) | [@pre-commit-ci](https://github.com/search?q=repo%3ANCAR%2Fxcollection+involves%3Apre-commit-ci+updated%3A2021-08-01..2021-11-24&type=Issues)
